==> ToolChain_STM32_1.0.46.tar.bz: ToolChain_STM32_1.0.46/ToolChain/install_22_Accelerometer_LIS3LV02DL.sh <==
#!/bin/bash
#
#
#  Install script for accelerometer device LIS3LV02DL
#  URL: 
#
#  Initial Script written by Gregor Rebel 2010-2012.
# 
#  Published under GNU Lesser General Public License
#  Check LEGAL.txt for details.
#
# Tested successfully on:
# openSuSE 12.1 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="400_sensor_lis3lv02dl"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

  if [ ! -e OK.Documentation ]; then #{
    dir ../../Documentation/Devices
    getFile http://www.st.com/internet/com/TECHNICAL_RESOURCES/TECHNICAL_LITERATURE/DATASHEET/ CD00091417.pdf ../../Documentation/Devices/Accelerometer_LIS3LV02DL.pdf                                    || ERROR="1"
    
    if [ "$Error" == "" ]; then
      echo "Documentation complete: $INSTALLPATH."
      touch OK.Documentation
    fi
  fi #}

  Name="$INSTALLPATH"
  createExtensionMakefileHead ${Name}      #{ create makefile
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name 

  vpath %.c additionals/common/sensors/accelerometer/
  INCLUDE_DIRS += -Iadditionals/common/sensors/accelerometer/
  
  MAIN_OBJS += lis3lv02dl.o

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  File="../extensions/activate.${Name}.sh" #{ create activate script
  createActivateScriptHead $File "$0" "Architecture independent support for Inter-integrated circuit interface (I2C)"
  cat <<END_OF_ACTIVATE >>$File
# available variables (-> scripts/installFuncs.sh:createActivateScriptHead())
#
# Paths to certain directories in current project folder
#   \$Dir_Extensions        -> extensions/
#   \$Dir_ExtensionsLocal   -> extensions.local/
#   \$Dir_ExtensionsActive  -> extensions.active/
#   \$Dir_Additionals       -> additionals/

# remove activated variants of same type
# rm 2>/dev/null \$Dir_Additionals/${Name}_*


# create links into extensions.active/
createLink "\$Dir_Extensions/makefile.$Name" "\$Dir_ExtensionsActive/makefile.$Name" '' QUIET

END_OF_ACTIVATE
  createActivateScriptTail $File $Name
  #}

  echo "Installed successfully: $Name"

  cd ..
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0

==> ToolChain_STM32_1.0.51.tar.bz: ToolChain_STM32_1.0.51/ToolChain/install_22_Accelerometer_LIS3LV02DL.sh <==
#!/bin/bash
#
#
#  Install script for accelerometer device LIS3LV02DL
#  URL: 
#
#  Initial Script written by Gregor Rebel 2010-2012.
# 
#  Published under GNU Lesser General Public License
#  Check LEGAL.txt for details.
#
# Tested successfully on:
# openSuSE 12.1 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="400_sensor_lis3lv02dl"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

  if [ ! -e OK.Documentation ]; then #{
    dir ../../Documentation/Devices
    getFile http://www.st.com/internet/com/TECHNICAL_RESOURCES/TECHNICAL_LITERATURE/DATASHEET/ CD00091417.pdf ../../Documentation/Devices/Accelerometer_LIS3LV02DL.pdf                                    || ERROR="1"
    
    if [ "$Error" == "" ]; then
      echo "Documentation complete: $INSTALLPATH."
      touch OK.Documentation
    fi
  fi #}

  Name="$INSTALLPATH"
  createExtensionMakefileHead ${Name}      #{ create makefile
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name 

  vpath %.c common/sensors/accelerometer/
  INCLUDE_DIRS += -Icommon/sensors/accelerometer/
  
  MAIN_OBJS += lis3lv02dl.o

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  File="../extensions/activate.${Name}.sh" #{ create activate script
  createActivateScriptHead $File "$0" "Architecture independent support for Inter-integrated circuit interface (I2C)"
  cat <<END_OF_ACTIVATE >>$File
# available variables (-> scripts/installFuncs.sh:createActivateScriptHead())
#
# Paths to certain directories in current project folder
#   \$Dir_Extensions        -> extensions/
#   \$Dir_ExtensionsLocal   -> extensions.local/
#   \$Dir_ExtensionsActive  -> extensions.active/
#   \$Dir_Additionals       -> additionals/

# remove activated variants of same type
# rm 2>/dev/null \$Dir_Additionals/${Name}_*


# create links into extensions.active/
createLink "\$Dir_Extensions/makefile.$Name" "\$Dir_ExtensionsActive/makefile.$Name" '' QUIET

activate.500_ttc_i2c.sh QUIET \"\$0\"

END_OF_ACTIVATE
  createActivateScriptTail $File $Name
  #}

  echo "Installed successfully: $Name"

  cd ..
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0
